#This is my first library Link:
https://www.youtube.com/watch?v=JsfIcV_4eik

PyPi: https://pypi.org/project/spruksakit/

Hi, this is my first Library

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install spruksakit

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from spruksakit import Spruksakit

   oh = Spruksakit()
   oh.show_name()
   oh.show_page()
   oh.show_youtube()
   oh.about()
   oh.show_art()

Developed by : Spruksakit FB: https://www.facebook.com/pruksakit
